@@ -79,18 +79,24 @@ module ActsAsTree
         configuration[:counter_cache] = :children_count
       end
 
-      belongs_to_opts = {
-        class_name:    name,
-        primary_key:   configuration[:primary_key],
-        foreign_key:   configuration[:foreign_key],
-        counter_cache: configuration[:counter_cache],
-        touch:         configuration[:touch],
-        inverse_of:    :children
-      }
-
-      belongs_to_opts[:optional] = true if ActiveRecord::VERSION::MAJOR >= 5
-
-      belongs_to :parent, belongs_to_opts
+      if ActiveRecord::VERSION::MAJOR >= 5
+        belongs_to :parent,
+          class_name:    name,
+          primary_key:   configuration[:primary_key],
+          foreign_key:   configuration[:foreign_key],
+          counter_cache: configuration[:counter_cache],
+          touch:         configuration[:touch],
+          inverse_of:    :children,
+          optional:      true
+      else
+        belongs_to :parent,
+          class_name:    name,
+          primary_key:   configuration[:primary_key],
+          foreign_key:   configuration[:foreign_key],
+          counter_cache: configuration[:counter_cache],
+          touch:         configuration[:touch],
+          inverse_of:    :children
+      end
 
       if ActiveRecord::VERSION::MAJOR >= 4
         has_many :children, lambda { order configuration[:order] },
@@ -100,7 +106,8 @@ module ActsAsTree
           dependent:   configuration[:dependent],
           inverse_of:  :parent
       else
-        has_many :children, class_name:  name,
+        has_many :children,
+          class_name:  name,
           primary_key: configuration[:primary_key],
           foreign_key: configuration[:foreign_key],
           order:       configuration[:order],
@@ -108,22 +115,19 @@ module ActsAsTree
           inverse_of:  :parent
       end
 
-      class_eval <<-EOV
-        include ActsAsTree::InstanceMethods
+      include ActsAsTree::InstanceMethods
 
-        def self.default_tree_order
-          order_option = #{configuration[:order].inspect}
-          order(order_option)
-        end
+      define_singleton_method :default_tree_order do
+        order(configuration[:order])
+      end
 
-        def self.root
-          self.roots.first
-        end
+      define_singleton_method :root do
+        self.roots.first
+      end
 
-        def self.roots
-          where(:#{configuration[:foreign_key]} => nil).default_tree_order
-        end
-      EOV
+      define_singleton_method :roots do
+        where(configuration[:foreign_key] => nil).default_tree_order
+      end
 
       # Returns a hash of all nodes grouped by their level in the tree structure.
       #
